#!/bin/sh
#
# update compiler links in /usr/libexec/ccache
#
# Written by: Hiromasa YOSHIMOTO <y@momonga-linux.org>

LIBDIR=/usr/libexec/ccache
BINDIR=/usr/bin

CCACHE=$BINDIR/ccache

function error
{
    echo $@ > /dev/stderr
    exit 1
}

function update_links 
{
    cd $LIBDIR || error "failed to cd $LIBDIR"

    while [ -n "$1" ]; do
	bin=$1
	shift

	[ -x $bin ] || continue

	name=`basename $bin`
	ln -s -f $CCACHE $name
    done
}

function remove_links
{
    cd $LIBDIR
    for name in *; do
	[ -L $name ] || continue
	type $name > /dev/null 2>&1 || rm -f $name
    done
}

[ -d $LIBDIR ] || error "ccache is not installed"
[ -x $CCACHE ] || error "ccache is not installed"

remove_links
 
update_links $BINDIR/cc{,-*,_*}
update_links $BINDIR/gcc{,-*,_*}
update_links $BINDIR/c++{,-*,_*}
update_links $BINDIR/g++{,-*,_*}
update_links $BINDIR/*-momonga-linux-cc{,-*,_*}
update_links $BINDIR/*-momonga-linux-gcc{,-*,_*}
update_links $BINDIR/*-momonga-linux-c++{,-*,_*}
update_links $BINDIR/*-momonga-linux-g++{,-*,_*}

exit 0